Documentation
¶
Index ¶
- func ExpireWithResult(rds *redis.Redis, key string, seconds int) (bool, error)
- func ExpireWithResultCtx(ctx context.Context, rds *redis.Redis, key string, seconds int) (bool, error)
- func MsetStrings(rds *redis.Redis, fieldsAndValues map[string]string) error
- func MsetStringsCtx(ctx context.Context, rds *redis.Redis, fieldsAndValues map[string]string) error
- func Msetnx(rds *redis.Redis, fieldsAndValues map[string]string) (bool, error)
- func MsetnxCtx(ctx context.Context, rds *redis.Redis, fieldsAndValues map[string]string) (bool, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExpireWithResult ¶
ExpireWithResult is like redis.Expire but returns the boolean result indicating whether the timeout was actually set.
func ExpireWithResultCtx ¶
func ExpireWithResultCtx(ctx context.Context, rds *redis.Redis, key string, seconds int) (bool, error)
ExpireWithResultCtx is like redis.ExpireCtx but returns the boolean result indicating whether the timeout was actually set.
func MsetStrings ¶
MsetStrings sets multiple key-value pairs where values are strings.
func MsetStringsCtx ¶
MsetStringsCtx sets multiple key-value pairs where values are strings.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.